/*******************************************************************************
 * Copyright (c) 2008 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.soda.sat.core.util;

import org.eclipse.soda.sat.core.internal.record.ExportProxyServiceRecord;

/**
 * Miscellaneous utilities.
 */
public class MiscUtility extends Object {
	//
	// Static Fields
	//

	// Singleton
	private static final MiscUtility INSTANCE = new MiscUtility();

	//
	// Static Methods
	//

	/**
	 * Public getter for the <code>MiscUtility</code> singleton instance.
	 *
	 * @return <code>MiscUtility</code>
	 */
	public static MiscUtility getInstance() {
		return MiscUtility.INSTANCE;
	}

	/**
	 * Constructor.
	 */
	private MiscUtility() {
		super();
	}

	//
	// Instance Methods
	//

	/**
	 * Estimate the size of a hashed collection based on the specified capacity.
	 * Unlike other collections, hashed collections need to be created bigger
	 * than the number of elements they intend to hold.  This method estimates
	 * how big a hashed collections must be to efficiently hold the specified
	 * number of elements without needing to grow.
	 *
	 * @param capacity  The number of elements the hash collections must hold.
	 * @return The estimate size of the hashed collection.
	 */
	public int estimateHashedCollectionSize(int capacity) {
		if (capacity <= 0) return 0;
		int size = capacity * 4 / 3 + 1;
		return size;
	}

	/**
	 * Unwrap the specified exported service proxy.
	 *
	 * @param serviceProxy  A service proxy.
	 * @return The unwrapped service.
	 * @throws IllegalArgumentException is thrown if the parameter is not a
	 * <code>Proxy</code>, or if the parameters is not a proxy for an exported
	 * service.
	 *
	 * @see org.eclipse.soda.sat.core.internal.record.ExportProxyServiceRecord#unwrapProxy(Object)
	 */
	public Object unwrapExportedServiceProxy(Object serviceProxy) throws IllegalArgumentException {
		Object object = ExportProxyServiceRecord.unwrapProxy(serviceProxy);
		return object;
	}
}
